@@ -16,4 +16,4 @@ class UCClusterPlanAdmin(admin.ModelAdmin):
 
 @admin.register(DevicePool)
 class DevicePoolPlanAdmin(admin.ModelAdmin):
-    list_display = ("devicepool", "tenant", "region", "description", "datetimegroup", "localroutegroup")
\ No newline at end of file
+    list_display = ("devicepool", "tenant", "region", "description", "datetimegroup", "localroutegroup", "cmgroup")
\ No newline at end of file
