@@ -164,7 +164,7 @@ class DevicePool(ChangeLoggedModel):
     localroutegroup = models.CharField(max_length=200)
     objects = RestrictedQuerySet.as_manager()
 
-    csv_headers = ['devicepool', 'tenant', 'description', 'region', 'datetimegroup', 'localroutegroup']
+    csv_headers = ['devicepool', 'tenant', 'description', 'region', 'datetimegroup', 'localroutegroup', 'cmgroup']
 
     def __str__(self):
         return str(self.devicepool)
